import type TransformingNetworkClient from '../../../communication/TransformingNetworkClient';
import { type MandateData } from '../../../data/customers/mandates/data';
import type Mandate from '../../../data/customers/mandates/Mandate';
import type Page from '../../../data/page/Page';
import type Callback from '../../../types/Callback';
import Binder from '../../Binder';
import { type CreateParameters, type GetParameters, type IterateParameters, type PageParameters, type RevokeParameters } from './parameters';
export default class CustomerMandatesBinder extends Binder<MandateData, Mandate> {
    protected readonly networkClient: TransformingNetworkClient;
    constructor(networkClient: TransformingNetworkClient);
    /**
     * Create a mandate for a specific customer. Mandates allow you to charge a customer's credit card, PayPal account or bank account recurrently.
     *
     * It is only possible to create mandates for IBANs and PayPal billing agreements with this endpoint. To create mandates for credit cards, have your customers perform a 'first payment' with their
     * credit card.
     *
     * @since 1.2.0
     * @see https://docs.mollie.com/reference/v2/mandates-api/create-mandate
     */
    create(parameters: CreateParameters): Promise<Mandate>;
    create(parameters: CreateParameters, callback: Callback<Mandate>): void;
    /**
     * Retrieve a mandate by its ID and its customer's ID. The mandate will either contain IBAN or credit card details, depending on the type of mandate.
     *
     * @since 1.2.0
     * @see https://docs.mollie.com/reference/v2/mandates-api/get-mandate
     */
    get(id: string, parameters: GetParameters): Promise<Mandate>;
    get(id: string, parameters: GetParameters, callback: Callback<Mandate>): void;
    /**
     * Retrieve all mandates for the given `customerId`, ordered from newest to oldest.
     *
     * The results are paginated. See pagination for more information.
     *
     * @since 3.0.0
     * @see https://docs.mollie.com/reference/v2/mandates-api/list-mandates
     */
    page(parameters: PageParameters): Promise<Page<Mandate>>;
    page(parameters: PageParameters, callback: Callback<Page<Mandate>>): void;
    /**
     * Retrieve all mandates for the given `customerId`, ordered from newest to oldest.
     *
     * The results are paginated. See pagination for more information.
     *
     * @since 3.6.0
     * @see https://docs.mollie.com/reference/v2/mandates-api/list-mandates
     */
    iterate(parameters: IterateParameters): import("../../../plumbing/iteration/HelpfulIterator").default<Mandate>;
    /**
     * Revoke a customer's mandate. You will no longer be able to charge the consumer's bank account or credit card with this mandate and all connected subscriptions will be canceled.
     *
     * @since 2.0.0
     * @see https://docs.mollie.com/reference/v2/mandates-api/revoke-mandate
     */
    revoke(id: string, parameters: RevokeParameters): Promise<true>;
    revoke(id: string, parameters: RevokeParameters, callback: Callback<true>): void;
}
