import type TransformingNetworkClient from '../../../communication/TransformingNetworkClient';
import type Page from '../../../data/page/Page';
import { type PaymentData } from '../../../data/payments/data';
import type Payment from '../../../data/payments/Payment';
import type Callback from '../../../types/Callback';
import Binder from '../../Binder';
import { type CreateParameters, type IterateParameters, type PageParameters } from './parameters';
export default class CustomerPaymentsBinder extends Binder<PaymentData, Payment> {
    protected readonly networkClient: TransformingNetworkClient;
    constructor(networkClient: TransformingNetworkClient);
    /**
     * Creates a payment for the customer.
     *
     * Linking customers to payments enables a number of [Mollie Checkout](https://www.mollie.com/products/checkout) features, including:
     *
     * -   Keeping track of payment preferences for your customers.
     * -   Enabling your customers to charge a previously used credit card with a single click.
     * -   Improved payment insights in your dashboard.
     * -   Recurring payments.
     *
     * @since 1.1.1
     * @see https://docs.mollie.com/reference/v2/customers-api/create-customer-payment
     */
    create(parameters: CreateParameters): Promise<Payment>;
    create(parameters: CreateParameters, callback: Callback<Payment>): void;
    /**
     * Retrieve all Payments linked to the Customer.
     *
     * @since 3.0.0
     * @see https://docs.mollie.com/reference/v2/customers-api/list-customer-payments
     */
    page(parameters: PageParameters): Promise<Page<Payment>>;
    page(parameters: PageParameters, callback: Callback<Page<Payment>>): void;
    /**
     * Retrieve all Payments linked to the Customer.
     *
     * @since 3.6.0
     * @see https://docs.mollie.com/reference/v2/customers-api/list-customer-payments
     */
    iterate(parameters: IterateParameters): import("../../../plumbing/iteration/HelpfulIterator").default<Payment>;
}
