import type TransformingNetworkClient from '../../communication/TransformingNetworkClient';
import { type OnboardingData } from '../../data/onboarding/data';
import type Onboarding from '../../data/onboarding/Onboarding';
import type Callback from '../../types/Callback';
import Binder from '../Binder';
import { type SubmitParameters } from './parameters';
export default class OnboardingBinder extends Binder<OnboardingData, Onboarding> {
    protected readonly networkClient: TransformingNetworkClient;
    constructor(networkClient: TransformingNetworkClient);
    /**
     * Get the status of onboarding of the authenticated organization.
     *
     * @since 3.2.0
     * @see https://docs.mollie.com/reference/v2/onboarding-api/get-onboarding-status
     */
    get(): Promise<Onboarding>;
    get(callback: Callback<Onboarding>): void;
    /**
     * Submit data that will be prefilled in the merchant's onboarding. The data you submit will only be processed when the onboarding status is `needs-data`.
     *
     * @since 3.2.0
     * @see https://docs.mollie.com/reference/v2/onboarding-api/submit-onboarding-data
     */
    submit(parameters?: SubmitParameters): Promise<true>;
    submit(parameters: SubmitParameters, callback: Callback<true>): void;
}
