import type TransformingNetworkClient from '../../../communication/TransformingNetworkClient';
import type Shipment from '../../../data/orders/shipments/Shipment';
import { type ShipmentData } from '../../../data/orders/shipments/Shipment';
import type Callback from '../../../types/Callback';
import Binder from '../../Binder';
import { type CreateParameters, type GetParameters, type ListParameters, type UpdateParameters } from './parameters';
export declare function getPathSegments(orderId: string): string;
export default class OrderShipmentsBinder extends Binder<ShipmentData, Shipment> {
    protected readonly networkClient: TransformingNetworkClient;
    constructor(networkClient: TransformingNetworkClient);
    /**
     * Create a shipment for specific order lines of an order.
     *
     * When using *Klarna Pay now*, *Klarna Pay later* and *Klarna Slice it*, using this endpoint is mandatory for the order amount to be captured. A capture will automatically be created for the
     * shipment.
     *
     * The word "shipping" is used in the figurative sense here. It can also mean that a service was provided or digital content was delivered.
     *
     * @since 3.0.0
     * @see https://docs.mollie.com/reference/v2/shipments-api/create-shipment
     */
    create(parameters: CreateParameters): Promise<Shipment>;
    create(parameters: CreateParameters, callback: Callback<Shipment>): void;
    /**
     * Retrieve a single shipment and the order lines shipped by a shipment's ID.
     *
     * @since 3.0.0
     * @see https://docs.mollie.com/reference/v2/shipments-api/get-shipment
     */
    get(id: string, parameters: GetParameters): Promise<Shipment>;
    get(id: string, parameters: GetParameters, callback: Callback<Shipment>): void;
    /**
     * Retrieve all shipments for an order.
     *
     * @since 3.0.0
     * @see https://docs.mollie.com/reference/v2/shipments-api/list-shipments
     */
    list(parameters: ListParameters): Promise<Shipment[]>;
    list(parameters: ListParameters, callback: Callback<Shipment[]>): void;
    /**
     * This endpoint can be used to update the tracking information of a shipment.
     *
     * @since 3.0.0
     * @see https://docs.mollie.com/reference/v2/shipments-api/update-shipment
     */
    update(id: string, parameters: UpdateParameters): Promise<Shipment>;
    update(id: string, parameters: UpdateParameters, callback: Callback<Shipment>): void;
}
