import type TransformingNetworkClient from '../../../communication/TransformingNetworkClient';
import type Page from '../../../data/page/Page';
import type Capture from '../../../data/payments/captures/Capture';
import { type CaptureData } from '../../../data/payments/captures/data';
import type Callback from '../../../types/Callback';
import Binder from '../../Binder';
import { type CreateParameters, type GetParameters, type IterateParameters, type PageParameters } from './parameters';
export default class PaymentCapturesBinder extends Binder<CaptureData, Capture> {
    protected readonly networkClient: TransformingNetworkClient;
    constructor(networkClient: TransformingNetworkClient);
    /**
     * Capture an *authorized* payment.
     *
     * @since 4.1.0
     * @see https://docs.mollie.com/reference/create-capture
     */
    create(parameters: CreateParameters): Promise<Capture>;
    create(parameters: CreateParameters, callback: Callback<Capture>): void;
    /**
     * Retrieve a single capture by its ID. Note the original payment's ID is needed as well.
     *
     * Captures are used for payments that have the *authorize-then-capture* flow. Mollie currently supports captures for **Cards** and **Klarna**.
     *
     * @since 1.1.1
     * @see https://docs.mollie.com/reference/v2/captures-api/get-capture
     */
    get(id: string, parameters: GetParameters): Promise<Capture>;
    get(id: string, parameters: GetParameters, callback: Callback<Capture>): void;
    /**
     * Retrieve all captures for a certain payment.
     *
     * Captures are used for payments that have the *authorize-then-capture* flow. Mollie currently supports captures for **Cards** and **Klarna**.
     *
     * @since 3.0.0
     * @see https://docs.mollie.com/reference/v2/captures-api/list-captures
     */
    page(parameters: PageParameters): Promise<Page<Capture>>;
    page(parameters: PageParameters, callback: Callback<Page<Capture>>): void;
    /**
     * Retrieve all captures for a certain payment.
     *
     * Captures are used for payments that have the *authorize-then-capture* flow. Mollie currently supports captures for **Cards** and **Klarna**.
     *
     * @since 3.6.0
     * @see https://docs.mollie.com/reference/v2/captures-api/list-captures
     */
    iterate(parameters: IterateParameters): import("../../../plumbing/iteration/HelpfulIterator").default<Capture>;
}
