import type TransformingNetworkClient from '../../../communication/TransformingNetworkClient';
import type Chargeback from '../../../data/chargebacks/Chargeback';
import { type ChargebackData } from '../../../data/chargebacks/Chargeback';
import type Page from '../../../data/page/Page';
import type Callback from '../../../types/Callback';
import Binder from '../../Binder';
import { type GetParameters, type IterateParameters, type PageParameters } from './parameters';
export default class PaymentChargebacksBinder extends Binder<ChargebackData, Chargeback> {
    protected readonly networkClient: TransformingNetworkClient;
    constructor(networkClient: TransformingNetworkClient);
    /**
     * Retrieve a single chargeback by its ID. Note the original payment's ID is needed as well.
     *
     * If you do not know the original payment's ID, you can use the chargebacks list endpoint.
     *
     * @since 1.1.1
     * @see https://docs.mollie.com/reference/v2/chargebacks-api/get-payment-chargeback
     */
    get(id: string, parameters: GetParameters): Promise<Chargeback>;
    get(id: string, parameters: GetParameters, callback: Callback<Chargeback>): void;
    /**
     * Retrieve all chargebacks filed for your payments.
     *
     * The results are paginated. See pagination for more information.
     *
     * @since 3.0.0
     * @see https://docs.mollie.com/reference/v2/chargebacks-api/list-chargebacks
     */
    page(parameters: PageParameters): Promise<Page<Chargeback>>;
    page(parameters: PageParameters, callback: Callback<Page<Chargeback>>): void;
    /**
     * Retrieve all chargebacks filed for your payments.
     *
     * The results are paginated. See pagination for more information.
     *
     * @since 3.6.0
     * @see https://docs.mollie.com/reference/v2/chargebacks-api/list-chargebacks
     */
    iterate(parameters: IterateParameters): import("../../../plumbing/iteration/HelpfulIterator").default<Chargeback>;
}
