import type TransformingNetworkClient from '../../../communication/TransformingNetworkClient';
import { type PaymentData } from '../../../data/payments/data';
import type Payment from '../../../data/payments/Payment';
import type Callback from '../../../types/Callback';
import Binder from '../../Binder';
import { type CreateParameters } from './parameters';
export default class OrderPaymentsBinder extends Binder<PaymentData, Payment> {
    protected readonly networkClient: TransformingNetworkClient;
    constructor(networkClient: TransformingNetworkClient);
    /**
     * An order has an automatically created payment that your customer can use to pay for the order. When the payment expires you can create a new payment for the order using this endpoint. A maximum
     * of 25 payments can be created for an order.
     *
     * A new payment can only be created while the status of the order is `created`, and when the status of the existing payment is either `expired`, `canceled` or `failed`.
     *
     * Note that order details (for example `amount` or `webhookUrl`) can not be changed using this endpoint.
     *
     * @since 3.1.0
     * @see https://docs.mollie.com/reference/v2/orders-api/create-order-payment
     */
    create(parameters: CreateParameters): Promise<Payment>;
    create(parameters: CreateParameters, callback: Callback<Payment>): void;
}
