import type TransformingNetworkClient from '../../../communication/TransformingNetworkClient';
import { type MethodData } from '../../../data/methods/data';
import type Method from '../../../data/methods/Method';
import type Callback from '../../../types/Callback';
import Binder from '../../Binder';
import { type Parameters } from './parameters';
export default class ProfileMethodsBinder extends Binder<MethodData, Method> {
    protected readonly networkClient: TransformingNetworkClient;
    constructor(networkClient: TransformingNetworkClient);
    /**
     * Enable a payment method on a specific or authenticated profile to use it with payments.
     *
     * The payment method `vouchers` cannot be enabled via this API. Instead, refer to /reference/v2/profiles-api/enable-voucher-issuer.
     *
     * @since 3.7.0
     * @see https://docs.mollie.com/reference/v2/profiles-api/enable-method
     */
    enable(parameters: Parameters): Promise<Method>;
    enable(parameters: Parameters, callback: Callback<Method>): void;
    /**
     * Disable a payment method on a specific or authenticated profile.
     *
     * @since 3.7.0
     * @see https://docs.mollie.com/reference/v2/profiles-api/disable-method
     */
    disable(parameters: Parameters): Promise<true>;
    disable(parameters: Parameters, callback: Callback<true>): void;
}
