import type TransformingNetworkClient from '../../../communication/TransformingNetworkClient';
import type IssuerModel from '../../../data/issuer/IssuerModel';
import { type IssuerData } from '../../../data/issuer/IssuerModel';
import type Callback from '../../../types/Callback';
import Binder from '../../Binder';
import { type CreateParameters, type Parameters } from './parameters';
export default class ProfileVoucherIssuersBinder extends Binder<IssuerData, IssuerModel> {
    protected readonly networkClient: TransformingNetworkClient;
    constructor(networkClient: TransformingNetworkClient);
    /**
     * Enable a voucher issuer on a specific or authenticated profile to use it with payments.
     *
     * @since 3.7.0
     * @see https://docs.mollie.com/reference/v2/profiles-api/enable-voucher-issuer
     */
    enable(parameters: CreateParameters): Promise<IssuerModel>;
    enable(parameters: CreateParameters, callback: Callback<IssuerModel>): void;
    /**
     * Disable a voucher issuer on a specific or authenticated profile.
     *
     * @since 3.7.0
     * @see https://docs.mollie.com/reference/v2/profiles-api/disable-voucher-issuer
     */
    disable(parameters: Parameters): Promise<true>;
    disable(parameters: Parameters, callback: Callback<true>): void;
}
