import type TransformingNetworkClient from '../../../communication/TransformingNetworkClient';
import type Page from '../../../data/page/Page';
import { type RefundData } from '../../../data/refunds/data';
import type Refund from '../../../data/refunds/Refund';
import type Callback from '../../../types/Callback';
import Binder from '../../Binder';
import { type CreateParameters, type IterateParameters, type PageParameters } from './parameters';
export declare function getPathSegments(orderId: string): string;
export default class OrderRefundsBinder extends Binder<RefundData, Refund> {
    protected readonly networkClient: TransformingNetworkClient;
    constructor(networkClient: TransformingNetworkClient);
    /**
     * When using the Orders API, refunds should be made for a specific order.
     *
     * If you want to refund arbitrary amounts, however, you can also use the Create payment refund endpoint for Pay later and Slice it by creating a refund on the payment itself.
     *
     * If an order line is still in the `authorized` status, it cannot be refunded. You should cancel it instead. Order lines that are `paid`, `shipping` or `completed` can be refunded.
     *
     * For more details on how refunds work, see /payments/refunds.
     *
     * @since 3.0.0
     * @see https://docs.mollie.com/reference/v2/refunds-api/create-order-refund
     */
    create(parameters: CreateParameters): Promise<Refund>;
    create(parameters: CreateParameters, callback: Callback<Refund>): void;
    /**
     * Retrieve a list of all refunds made for a specific order.
     *
     * The results are paginated. See pagination for more information.
     *
     * @since 3.0.0
     * @see https://docs.mollie.com/reference/v2/refunds-api/list-order-refunds
     */
    page(parameters: PageParameters): Promise<Page<Refund>>;
    page(parameters: PageParameters, callback: Callback<Page<Refund>>): void;
    /**
     * Retrieve a list of all refunds made for a specific order.
     *
     * The results are paginated. See pagination for more information.
     *
     * @since 3.6.0
     * @see https://docs.mollie.com/reference/v2/refunds-api/list-order-refunds
     */
    iterate(parameters: IterateParameters): import("../../../plumbing/iteration/HelpfulIterator").default<Refund>;
}
