import type TransformingNetworkClient from '../../../communication/TransformingNetworkClient';
import type Page from '../../../data/page/Page';
import { type PaymentData } from '../../../data/payments/data';
import type Payment from '../../../data/payments/Payment';
import type Callback from '../../../types/Callback';
import Binder from '../../Binder';
import { type IterateParameters, type PageParameters } from './parameters';
export declare function getPathSegments(settlementId: string): string;
export default class SettlementPaymentsBinder extends Binder<PaymentData, Payment> {
    protected readonly networkClient: TransformingNetworkClient;
    constructor(networkClient: TransformingNetworkClient);
    /**
     * Retrieve all Payments included in a Settlement.
     *
     * Note that payments for Klarna payment methods are not listed in here. These payment methods are settled using captures. To retrieve the captures, use the List settlement captures endpoint.
     *
     * @since 3.7.0
     * @see https://docs.mollie.com/reference/v2/settlements-api/list-settlement-payments
     */
    page(parameters: PageParameters): Promise<Page<Payment>>;
    page(parameters: PageParameters, callback: Callback<Page<Payment>>): void;
    /**
     * Retrieve all Payments included in a Settlement.
     *
     * Note that payments for Klarna payment methods are not listed in here. These payment methods are settled using captures. To retrieve the captures, use the List settlement captures endpoint.
     *
     * @since 3.7.0
     * @see https://docs.mollie.com/reference/v2/settlements-api/list-settlement-payments
     */
    iterate(parameters: IterateParameters): import("../../../plumbing/iteration/HelpfulIterator").default<Payment>;
}
