import type TransformingNetworkClient from '../../communication/TransformingNetworkClient';
import type Callback from '../../types/Callback';
import Binder from '../Binder';
import { type PageParameters, IterateParameters } from './parameters';
import { Page } from '../../types';
import Terminal from '../../data/terminals/Terminal';
import type { TerminalData } from '../../data/terminals/data';
export default class TerminalsBinder extends Binder<TerminalData, Terminal> {
    protected readonly networkClient: TransformingNetworkClient;
    constructor(networkClient: TransformingNetworkClient);
    /**
     * Retrieve a single terminal object by its terminal ID. This terminal object symbolizes the physical device that you have received from us.
     *
     * For more information on accepting point-of-sale payments, please refer to the [point-of-sale guide](https://docs.mollie.com/point-of-sale/overview).
     *
     * @since 4.3.0
     * @see https://docs.mollie.com/reference/v2/terminals-api/get-terminal
     */
    get(id: string): Promise<Terminal>;
    get(id: string, callback: Callback<Terminal>): void;
    /**
     * Retrieve a list of all of your terminals.
     *
     * The results are paginated. See pagination for more information.
     *
     * @since 4.3.0
     * @see https://docs.mollie.com/reference/v2/terminals-api/list-terminals
     */
    page(parameters?: PageParameters): Promise<Page<Terminal>>;
    page(parameters: PageParameters, callback: Callback<Page<Terminal>>): void;
    /**
     * Retrieve a list of all of your terminals.
     *
     * The results are paginated. See pagination for more information.
     *
     * @since 4.3.0
     * @see https://docs.mollie.com/reference/v2/terminals-api/list-terminals
     */
    iterate(parameters?: IterateParameters): import("../../plumbing/iteration/HelpfulIterator").default<Terminal>;
}
